==> fluxbox-0.9.13.tar.bz2: fluxbox-0.9.13/nls/it_IT/Translation.m <==
$ codeset=ISO-8859-1

$set 1 #Align

1 In basso al centro
2 In basso a sinistra
3 In basso a destra
4 Orizzontale
6 A sinistra in basso
7 A sinistra al centro
8 A sinistra in alto
11 A destra in basso
12 A destra al centro
13 A destra in alto
14 In alto al centro
15 In alto a sinistra
16 In alto a destra
17 Verticale

$set 2 #BaseDisplay


$set 3 #Common


$set 4 #Configmenu

2 In primo piano automaticamente
4 Clicca per focalizzare
7 Focalizza l'ultima finestra nell'area di lavoro
8 Tipo di focalizzazione
9 Focalizza le nuove finestre
10 Massimo ingrandimento
11 Simulazione di colore nelle immagini
12 Mostra il contenuto spostando le finestre
13 Focalizzazione semiautomatica
14 Focalizzazione automatica
15 Cambia area di lavoro trascinando le finestre

$set 5 #Ewmh


$set 6 #FbTkError


$set 7 #Fluxbox


$set 8 #Gnome


$set 9 #Keys


$set 10 #Menu

3 Uscita
4 Icone
7 Posizionamento
9 Riavvio
10 xterm

$set 11 #Remember


$set 12 #Screen

2 W: %4d x H: %4d
5 X: %4d x Y: %4d
6 0: 0000 x 0: 0000

$set 13 #Slit

4 Direzione dello slit
7 Posizionamento dello slit
8 Slit

$set 14 #Toolbar

1 Cambia nome a questa area di lavoro
10 Posizionamento della Toolbar
11 Toolbar

$set 15 #Window

1 Senza nome

$set 16 #Windowmenu

1 Chiudi
2 Riduci a icona
4 Sullo sfondo
5 Ingrandisci
6 In primo piano
7 Manda a ...
8 Riduci a barra
9 Su tutte le aree di lavoro

$set 17 #Workspace

1 Area di lavoro %d
2 Aree di lavoro
3 Crea una nuova
4 Elimina l'ultima

$set 18 #bsetroot

1 %s: errore: specicare una delle opzioni : -solid, -mod, -gradient\n
3 %s 2.0: (c) 1997-2000 Brad Hughes\n\n\
-display <stringa>        connessione al display\n\
-mod <x> <y>              schema\n\
-foreground, -fg <colore> colore di primo piano nello schema\n\
-background, -bg <colore> colore di sfondo nello schema\n\n\
-gradient <texture>       tipo di gradazione\n\
-from <colore>            colore di partenza dela gradazione\n\
-to <colore>              colore finale dela gradazione\n\n\
-solid <colore>           colore semplice\n\n\
-help                     mostra questo messaggio ed esci\n

$set 19 #main

1 errore: '-display' richiede un argomento\n
11 errore: '-rc' richiede un argomento\n
12 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <stringa>\t\tusa la connessione al display.\n\
-rc <stringa>\t\t\tusa un file di configurazione alternativo.\n\
-version\t\t\tmostra la versione ed esci.\n\
-info\t\t\t\tdisplay some useful information.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\tmostra questo messaggio di aiuto ed esci.\n\n

==> fluxbox-1.0rc2.tar.bz2: fluxbox-1.0rc2/nls/it_IT/Translation.m <==
$ codeset=ISO-8859-1

$set 1 #Align

1 In basso al centro
2 In basso a sinistra
3 In basso a destra
4 Orizzontale
6 A sinistra in basso
7 A sinistra al centro
8 A sinistra in alto
11 A destra in basso
12 A destra al centro
13 A destra in alto
14 In alto al centro
15 In alto a sinistra
16 In alto a destra
17 Verticale

$set 2 #BaseDisplay


$set 3 #Common


$set 4 #Configmenu

2 In primo piano automaticamente
4 Clicca per focalizzare
7 Focalizza l'ultima finestra nell'area di lavoro
8 Tipo di focalizzazione
9 Focalizza le nuove finestre
10 Massimo ingrandimento
11 Simulazione di colore nelle immagini
12 Mostra il contenuto spostando le finestre
13 Focalizzazione semiautomatica
14 Focalizzazione automatica
15 Cambia area di lavoro trascinando le finestre

$set 5 #Ewmh


$set 6 #FbTkError


$set 7 #Fluxbox


$set 8 #Gnome


$set 9 #Keys


$set 10 #Menu

3 Uscita
4 Icone
7 Posizionamento
9 Riavvio

$set 11 #Remember


$set 12 #Screen

2 W: %4d x H: %4d

$set 13 #Slit

4 Direzione dello slit
7 Posizionamento dello slit
8 Slit

$set 14 #Toolbar

1 Cambia nome a questa area di lavoro
10 Posizionamento della Toolbar
11 Toolbar

$set 15 #Window

1 Senza nome

$set 16 #Windowmenu

1 Chiudi
2 Riduci a icona
4 Sullo sfondo
5 Ingrandisci
6 In primo piano
7 Manda a ...
8 Riduci a barra
9 Su tutte le aree di lavoro

$set 17 #Workspace

1 Area di lavoro %d
2 Aree di lavoro
3 Crea una nuova
4 Elimina l'ultima

$set 18 #fbsetroot

1 errore: specicare una delle opzioni : -solid, -mod, -gradient\n
3 -display <stringa>        connessione al display\n\
-mod <x> <y>              schema\n\
-foreground, -fg <colore> colore di primo piano nello schema\n\
-background, -bg <colore> colore di sfondo nello schema\n\n\
-gradient <texture>       tipo di gradazione\n\
-from <colore>            colore di partenza dela gradazione\n\
-to <colore>              colore finale dela gradazione\n\n\
-solid <colore>           colore semplice\n\n\
-help                     mostra questo messaggio ed esci\n

$set 19 #main

1 errore: '-display' richiede un argomento
11 errore: '-rc' richiede un argomento
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <stringa>\t\tusa la connessione al display.\n\
-rc <stringa>\t\t\tusa un file di configurazione alternativo.\n\
-version\t\t\tmostra la versione ed esci.\n\
-info\t\t\t\tdisplay some useful information.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\tmostra questo messaggio di aiuto ed esci.\n\n
